@@ -1,5 +1,9 @@
-////////////////////////////////////////////
-/// MeshedChannels
+//! This module contains the macros
+//! for creating MeshedChannels for any number
+//! of participants.
+//!
+//! *This module is available only if MultiCrusty is built with
+//! the `"macros_multiple"` feature.*
 
 /// Creates a MeshedChannels for more than 3 participants.
 ///
@@ -12,11 +16,14 @@
 ///
 /// ```
 /// use mpstthree::create_meshedchannels;
-/// use mpstthree::role::Role;
 ///
 /// create_meshedchannels!(MeshedChannels, 3);
 /// ```
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_multiple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_multiple")))]
 macro_rules! create_meshedchannels {
     ($meshedchannels_name: ident, $nsessions: literal) => {
         mpst_seq::create_meshedchannels!($meshedchannels_name, $nsessions);
