@@ -1,3 +1,7 @@
+//! This module contains the required definitions and
+//! functions for a role to broadcast multiple choices.
+//! Its dual is it self.
+
 use crossbeam_channel::{bounded, Receiver, Sender};
 
 /// This structure is used for closing a stack for an active role
@@ -6,15 +10,19 @@ use crossbeam_channel::{bounded, Receiver, Sender};
 /// # Example
 ///
 /// ```
+/// use mpstthree::role::Role; // Only used for example
 /// use mpstthree::role::broadcast::RoleBroadcast;
 /// use mpstthree::role::a::RoleA;
-/// use mpstthree::role::end::RoleEnd;
 ///
 /// type BroadcastA = RoleA<RoleBroadcast>;
+///
+/// let _ = BroadcastA::new(); // Only used for example
 /// ```
 #[derive(Debug)]
 pub struct RoleBroadcast {
+    #[doc(hidden)]
     pub sender: Sender<()>,
+    #[doc(hidden)]
     pub receiver: Receiver<()>,
 }
 
