@@ -1,3 +1,10 @@
+//! This module contains the functions for
+//! receiving a payload
+//! for a TCP connection.
+//!
+//! *This module is available only if MultiCrusty is built with
+//! the `"transport"` feature.*
+
 use crate::binary::struct_trait::{recv::Recv, session::Session};
 use std::boxed::Box;
 use std::error::Error;
@@ -12,6 +19,10 @@ type TupleRecv<T, S> = (T, S, TcpData, usize, TcpStream);
 /// Receive a value of type `T`. Can fail. Returns either a
 /// pair of the received value and the continuation of the
 /// session `S` or an error.
+///
+/// *This function is available only if MultiCrusty is built with
+/// the `"transport"` feature.*
+#[cfg_attr(doc_cfg, doc(cfg(feature = "transport")))]
 pub fn recv_tcp<T, S>(
     s: Recv<(T, TcpData), S>,
     mut stream: TcpStream,
