@@ -1,3 +1,10 @@
+//! This module contains the functions for
+//! sending a payload
+//! for a TCP connection.
+//!
+//! *This module is available only if MultiCrusty is built with
+//! the `"transport"` feature.*
+
 use crate::binary::struct_trait::{send::Send, session::Session};
 use std::boxed::Box;
 use std::error::Error;
@@ -10,6 +17,10 @@ type TcpData = [u8; 128];
 
 /// Send a value of type `T` over tcp. Returns the
 /// continuation of the session `S`. May fail.
+///
+/// *This function is available only if MultiCrusty is built with
+/// the `"transport"` feature.*
+#[cfg_attr(doc_cfg, doc(cfg(feature = "transport")))]
 pub fn send_tcp<T, S>(
     x: T, // Need to force x and data to be of the same type but for choice/offer
     data: &TcpData,
